@@ -165,7 +165,7 @@ def runImage(data=None,type=None):
         try:
             Config.build_dir = Config.sast_build_dir
             container= docker.containers.run(docker_image, command_line, volumes={Config.sast_build_dir: {
- 			 	'bind': data['bind']}},user=1000,detach=detach)
+ 			 	'bind': data['bind']}},user=userid,detach=detach)
             
             #print(output_file,toolname,tool_id,scan_details_id)
             logging.info('[SUCCESS]: %s Scan Completed',tool_name)
